# Attribute

## ::: xdsl.ir.Attribute

    options:
      members:
        - name
        - verify
      show_root_heading: true

## ::: xdsl.ir.Data

    options:
      members:
        - data
        - print_parameter
        - parse_parameter
      show_root_heading: true

## ::: xdsl.ir.ParametrizedAttribute

    options:
      members:
        - parameters
        - print_parameters
        - parse_parameters
        - get_irdl_definition
      show_root_heading: true

## ::: xdsl.ir.TypedAttribute

    options:
      members:
        - parameters
        - print_parameters
        - parse_parameters
        - get_irdl_definition
      show_root_heading: true
